@@ -9,14 +9,10 @@ RibDif2 contains the following moduels:
 """
 __authors__ = "Robert Murphy"
 __licence__ = "GPL-3.0"
-__version__ = (1, 1, 0)
+__version__ = (1, 1, 1)
 
 
 # Try on python v3.5
 import sys as _sys
-if _sys.version_info[:2] < (3, 5):
-    raise ImportError('Python version must be >= 3.5')
-    
-
-from . import ngd_download
-from . import barrnap_run
\ No newline at end of file
+if _sys.version_info[:2] < (3, 7):
+    raise ImportError('Python version must be >= 3.7')
\ No newline at end of file
